@@ -15,26 +15,26 @@ from bokeh.models import HoverTool
 from bokeh.plotting import ColumnDataSource, figure
 
 from ..config import config
-from ..models import terminal # noqa
-from ..pane import Bokeh, HTML
-from ..layout import Accordion, Column, Row, Tabs, FlexBox
+from ..depends import bind
+from ..layout import (
+    Accordion, Column, FlexBox, Row, Tabs,
+)
+from ..pane import HTML, Bokeh
 from ..template import FastListTemplate
-from ..widgets import MultiSelect, Terminal, TextInput
+from ..widgets import (
+    Button, MultiSelect, Tabulator, TextInput,
+)
 from ..widgets.indicators import Trend
 from .logging import (
-    LOG_SESSION_CREATED, LOG_SESSION_LAUNCHING, LOG_SESSION_DESTROYED,
-    panel_logger
+    LOG_SESSION_CREATED, LOG_SESSION_DESTROYED, LOG_SESSION_LAUNCHING,
+    panel_logger,
 )
 from .notebook import push_notebook
 from .profile import profiling_tabs
 from .server import set_curdoc
 from .state import state
 
-try:
-    import psutil
-    process = psutil.Process(os.getpid())
-except Exception:
-    process = None
+PROCESSES = {}
 
 log_sessions = []
 
@@ -47,11 +47,7 @@ class LogFilter(logging.Filter):
         if session_id in log_sessions:
             return False
         elif session_id not in session_filter.options:
-            session_filter.options = session_filter.options + [session_id]
-        if session_filter.value and session_id not in session_filter.value:
-            return False
-        if name_filter.value and name_filter.value not in record.name:
-            return False
+            session_filter.options = [session_id] + session_filter.options
         return True
 
 
@@ -73,11 +69,53 @@ class LogDataHandler(logging.StreamHandler):
         self._data.param.trigger('data')
 
 
+class _LogTabulator(Tabulator):
+
+    _update_defaults = {
+        "theme": "midnight",
+        "layout": "fit_data_stretch",
+        "show_index": False,
+        "sorters": [{'field': 'datetime', 'dir': 'dsc'}],
+        "disabled": True,
+        "pagination": "local",
+        "page_size": 18,
+    }
+
+    def __init__(self, **params):
+        params["value"] = self._create_frame()
+        params = {**self._update_defaults, **params}
+        super().__init__(**params)
+
+    @staticmethod
+    def _create_frame(data=None):
+        columns=["datetime", "level", "app", "session", "message"]
+        if data is None:
+            return pd.DataFrame(columns=columns)
+        else:
+            return pd.Series(data, index=columns)
+
+    def write(self, log):
+        # Example of a log message:
+        # '2022-07-13 14:38:04,803 INFO: panel.io.server - Session 140255299576448 launching\n'
+        try:
+            s = log.strip().split(" ")
+            datetime = f"{s[0]} {s[1]}"
+            level = s[2][:-1]
+            app = s[3]
+            session = int(s[6])
+            message = " ".join(s[7:])
+            df = self._create_frame([datetime, level, app, session, message])
+
+            self.stream(df, follow=False)
+        except Exception:
+            pass
+
+
 # Set up logging
 data = Data()
 log_data_handler = LogDataHandler(data)
 log_handler = logging.StreamHandler()
-log_handler.setLevel('DEBUG')
+log_handler.setLevel(config.admin_log_level)
 panel_logger.addHandler(log_handler)
 panel_logger.addHandler(log_data_handler)
 
@@ -86,11 +124,41 @@ log_handler.addFilter(log_filter)
 log_data_handler.addFilter(log_filter)
 formatter = logging.Formatter('%(asctime)s %(levelname)s: %(name)s - %(message)s')
 log_handler.setFormatter(formatter)
-log_terminal = Terminal(sizing_mode='stretch_both', min_height=400)
+log_terminal = _LogTabulator(sizing_mode='stretch_both', min_height=400)
 log_handler.setStream(log_terminal)
 
 session_filter = MultiSelect(name='Filter by session', options=[])
-name_filter = TextInput(name='Filter by component')
+message_filter = TextInput(name='Filter by message')
+level_filter = MultiSelect(name="Filter by level", options=["DEBUG", "INFO", "WARNING", "ERROR"])
+app_filter = TextInput(name='Filter by app')
+
+def _textinput_filter(df, pattern, column):
+    if not pattern or df.empty:
+        return df
+    return df[df[column].str.contains(pattern)].copy()
+
+log_terminal.add_filter(level_filter, 'level')
+log_terminal.add_filter(bind(_textinput_filter, pattern=app_filter, column='app'))
+log_terminal.add_filter(session_filter, 'session')
+log_terminal.add_filter(bind(_textinput_filter, pattern=message_filter, column='message'))
+
+
+def _clear_log_filters(*events):
+    level_filter.value = []
+    app_filter.value = ""
+    session_filter.value = []
+    message_filter.value = ""
+
+
+reset_filter = Button(name="Clear filters")
+reset_filter.on_click(_clear_log_filters)
+
+
+download_filename, download_button = log_terminal.download_menu(
+    text_kwargs={'name': 'Enter filename for logfile', 'value': 'log.csv'},
+    button_kwargs={'name': 'Download logfile'}
+)
+
 
 EVENT_TYPES = {
     'initializing': 'MediumSeaGreen',
@@ -218,7 +286,10 @@ def get_timeline(doc=None):
             push_notebook(bk_pane)
 
     for record in log_data_handler._data.data:
-        update_cds(record)
+        try:
+            update_cds(record)
+        except Exception:
+            pass
 
     def schedule_cds_update(event):
         new = event.new[-1]
@@ -249,11 +320,19 @@ def get_version_info():
     Param: {param.__version__}</br>
     </code>""", width=300, height=300, margin=(0, 5))
 
+def get_process():
+    import psutil
+    if os.getpid() in PROCESSES:
+        process = PROCESSES[os.getpid()]
+    else:
+        PROCESSES[os.getpid()] = process = psutil.Process(os.getpid())
+    return process
+
 def get_mem():
-    return pd.DataFrame([(time.time(), process.memory_info().rss/1024/1024)], columns=['time', 'memory'])
+    return pd.DataFrame([(time.time(), get_process().memory_info().rss/1024/1024)], columns=['time', 'memory'])
 
 def get_cpu():
-    return pd.DataFrame([(time.time(), process.cpu_percent())], columns=['time', 'cpu'])
+    return pd.DataFrame([(time.time(), get_process().cpu_percent())], columns=['time', 'cpu'])
 
 def get_process_info():
     memory = Trend(
@@ -264,14 +343,12 @@ def get_process_info():
         data=get_cpu(), plot_x='time', plot_y='cpu', plot_type='step',
         title='CPU Usage (%)', width=300, height=300
     )
-    def update_memory(): memory.stream(get_mem())
-    def update_cpu(): cpu.stream(get_cpu())
-    mem_cb = state.add_periodic_callback(update_memory, period=1000, start=False)
-    cpu_cb = state.add_periodic_callback(update_cpu, period=1000, start=False)
-    mem_cb.log = False
-    cpu_cb.log = False
-    mem_cb.start()
-    cpu_cb.start()
+    def update_stats():
+        memory.stream(get_mem())
+        cpu.stream(get_cpu())
+    stats_cb = state.add_periodic_callback(update_stats, period=1000, start=False)
+    stats_cb.log = False
+    stats_cb.start()
     return memory, cpu
 
 def get_session_data():
@@ -337,19 +414,32 @@ def get_session_info(doc=None):
 def get_overview(doc=None):
     layout = FlexBox(*get_session_info(doc), margin=0, sizing_mode='stretch_width')
     info = get_version_info()
-    if process is None:
+    try:
+        import psutil  # noqa
+    except Exception:
         layout.append(info)
         return layout
-    layout.extend([*get_process_info(), info])
-    return layout
+    else:
+        layout.extend([*get_process_info(), info])
+        return layout
 
 
 def log_component():
+    # Without this tabulator is empty after reload of website
+    log_terminal.param.trigger("value")
+
     return Column(
         Accordion(
-            ('Filters', Row(
+            ('Filters & Download', Row(
+                level_filter,
+                app_filter,
                 session_filter,
-                name_filter,
+                message_filter,
+                Column(
+                    download_filename,
+                    download_button,
+                    reset_filter,
+                ),
                 sizing_mode='stretch_width'
             )),
             active=[],
@@ -361,14 +451,13 @@ def log_component():
         sizing_mode='stretch_both'
     )
 
-
-def admin_panel(doc):
-    # Add and remove admin panel app from log sessions list
+def admin_template(doc):
     log_sessions.append(id(doc))
     def _remove_log_session(session_context):
         log_sessions.remove(id(doc))
     doc.on_session_destroyed(_remove_log_session)
 
+    # Add and remove admin panel app from log sessions list
     # Set up admin panel
     template = FastListTemplate(title='Admin Panel', theme='dark')
     tabs = Tabs(
@@ -385,7 +474,14 @@ def admin_panel(doc):
         ('User Profiling', profiling_tabs(state, None, r'^\/.*')),
         ('Logs', log_component())
     ])
+    tabs.extend([
+        (name, plugin()) for name, plugin in config.admin_plugins
+    ])
     template.main.append(tabs)
+    return template
+
+def admin_panel(doc):
     with set_curdoc(doc):
+        template = admin_template(doc)
         template.server_doc(doc)
     return doc
