@@ -65,7 +65,8 @@ def _cleanup_doc(doc):
             callback(None)
         except Exception:
             pass
-    doc.callbacks._change_callbacks[None] = {}
+    if hasattr(doc.callbacks, '_change_callbacks'):
+        doc.callbacks._change_callbacks[None] = {}
 
     # Remove views
     from ..viewable import Viewable
@@ -192,18 +193,18 @@ def unlocked() -> Iterator:
     curdoc = state.curdoc
     session_context = getattr(curdoc, 'session_context', None)
     session = getattr(session_context, 'session', None)
-    if (curdoc is None or session_context is None or session is None):
+    if curdoc is None or session_context is None or session is None or state._jupyter_kernel_context:
         yield
         return
+    elif curdoc.callbacks.hold_value:
+        yield
+        monkeypatch_events(curdoc.callbacks._held_events)
+        return
+
     from tornado.websocket import WebSocketClosedError, WebSocketHandler
     connections = session._subscribed_connections
 
-    hold = curdoc.callbacks.hold_value
-    if hold:
-        old_events = list(curdoc.callbacks._held_events)
-    else:
-        old_events = []
-        curdoc.hold()
+    curdoc.hold()
     try:
         yield
 
@@ -218,7 +219,7 @@ def unlocked() -> Iterator:
         monkeypatch_events(events)
         remaining_events, futures = [], []
         for event in events:
-            if not isinstance(event, ModelChangedEvent) or event in old_events or locked:
+            if not isinstance(event, ModelChangedEvent) or locked:
                 remaining_events.append(event)
                 continue
             for conn in connections:
@@ -238,14 +239,15 @@ def unlocked() -> Iterator:
                     logger.warning(f"Failed sending message due to following error: {e}")
 
         if state._unblocked(curdoc):
-            asyncio.ensure_future(handle_write_errors())
+            try:
+                asyncio.ensure_future(handle_write_errors())
+            except RuntimeError:
+                curdoc.add_next_tick_callback(handle_write_errors)
         else:
             curdoc.add_next_tick_callback(handle_write_errors)
 
         curdoc.callbacks._held_events = remaining_events
     finally:
-        if hold:
-            return
         try:
             curdoc.unhold()
         except RuntimeError:
