@@ -1,3 +1,7 @@
+from __future__ import annotations
+
+from typing import TYPE_CHECKING, ClassVar, Mapping
+
 import param
 
 from bokeh.models import Column as BkColumn, CustomJS
@@ -5,6 +9,9 @@ from bokeh.models import Column as BkColumn, CustomJS
 from .base import NamedListPanel
 from .card import Card
 
+if TYPE_CHECKING:
+    from bokeh.model import Model
+
 
 class Accordion(NamedListPanel):
     """
@@ -42,7 +49,7 @@ class Accordion(NamedListPanel):
 
     _bokeh_model = BkColumn
 
-    _rename = {'active': None, 'active_header_background': None,
+    _rename: ClassVar[Mapping[str, str | None]] = {'active': None, 'active_header_background': None,
                'header_background': None, 'objects': 'children',
                'dynamic': None, 'toggle': None, 'header_color': None}
 
@@ -122,7 +129,7 @@ class Accordion(NamedListPanel):
         self._update_active()
         return new_models
 
-    def _cleanup(self, root):
+    def _cleanup(self, root: Model | None = None) -> None:
         for panel in self._panels.values():
             panel._cleanup(root)
         super()._cleanup(root)
