@@ -5,6 +5,10 @@ import {Model} from "@bokehjs/model"
 import {Message} from "@bokehjs/protocol/message"
 import {Receiver} from "@bokehjs/protocol/receiver"
 
+export const comm_settings: any = {
+  debounce: true
+}
+
 export class CommManagerView extends View {
   model: CommManager
 
@@ -44,8 +48,20 @@ export class CommManager extends Model {
       console.log("Could not find comm manager on window.PyViz, ensure the extension is loaded.")
     else {
       this.ns = (window as any).PyViz
-      this.ns.comm_manager.register_target(this.plot_id, this.comm_id, (msg: any) => this.msg_handler(msg))
+      this.ns.comm_manager.register_target(this.plot_id, this.comm_id, (msg: any) => {
+	for (const view of this.ns.shared_views.get(this.plot_id)) {
+	  if (view !== this)
+	    view.msg_handler(msg)
+	}
+	this.msg_handler(msg)
+      })
       this._client_comm = this.ns.comm_manager.get_client_comm(this.plot_id, this.client_comm_id, (msg: any) => this.on_ack(msg));
+      if (this.ns.shared_views == null)
+	this.ns.shared_views = new Map()
+      if (this.ns.shared_views.has(this.plot_id))
+	this.ns.shared_views.get(this.plot_id).push(this)
+      else
+	this.ns.shared_views.set(this.plot_id, [this])
     }
   }
 
@@ -67,7 +83,9 @@ export class CommManager extends Model {
       return
 
     this._event_buffer.push(event);
-    if ((!this._blocked || (Date.now() > this._timeout))) {
+    if (!comm_settings.debounce) {
+      this.process_events()
+    } else if ((!this._blocked || (Date.now() > this._timeout))) {
       setTimeout(() => this.process_events(), this.debounce);
       this._blocked = true;
       this._timeout = Date.now()+this.timeout;
@@ -81,6 +99,15 @@ export class CommManager extends Model {
     this._event_buffer = [];
     const message = Message.create('PATCH-DOC', {}, patch)
     this._client_comm.send(message)
+    for (const view of this.ns.shared_views.get(this.plot_id)) {
+      if (view !== this && view.document != null)
+	view.document.apply_json_patch(patch, [], this.id)
+    }
+  }
+
+  disconnect_signals(): void {
+    super.disconnect_signals()
+    this.ns.shared_views.shared_views.delete(this.plot_id)
   }
 
   on_ack(msg: any) {
