@@ -1,7 +1,9 @@
-from bokeh.core.properties import Bool, List, Nullable, String
-
+from bokeh.core.properties import (
+    Bool, List, Nullable, String,
+)
 from bokeh.models import Column
 
+
 class Card(Column):
 
     active_header_background = Nullable(String, help="Background color of active Card header.")
