@@ -2,15 +2,26 @@
 Defines a PlotlyPane which renders a plotly plot using PlotlyPlot
 bokeh model.
 """
+from __future__ import annotations
+
+from typing import (
+    TYPE_CHECKING, Any, ClassVar, Mapping, Optional,
+)
+
 import numpy as np
 import param
 
 from bokeh.models import ColumnDataSource
 from pyviz_comms import JupyterComm
 
-from .base import PaneBase
 from ..util import isdatetime, lazy_load
 from ..viewable import Layoutable
+from .base import PaneBase
+
+if TYPE_CHECKING:
+    from bokeh.document import Document
+    from bokeh.model import Model
+    from pyviz_comms import Comm
 
 
 class Plotly(PaneBase):
@@ -41,6 +52,10 @@ class Plotly(PaneBase):
 
     hover_data = param.Dict(doc="Hover callback data")
 
+    link_figure = param.Boolean(default=True, doc="""
+       Attach callbacks to the Plotly figure to update output when it
+       is modified in place.""")
+
     relayout_data = param.Dict(doc="Relayout callback data")
 
     restyle_data = param.List(doc="Restyle callback data")
@@ -66,12 +81,14 @@ class Plotly(PaneBase):
     _render_count = param.Integer(default=0, doc="""
         Number of renders, increment to trigger re-render""")
 
-    priority = 0.8
+    priority: ClassVar[float | bool | None] = 0.8
 
-    _updates = True
+    _updates: ClassVar[bool] = True
+
+    _rename: ClassVar[Mapping[str, str | None]] = {'link_figure': None}
 
     @classmethod
-    def applies(cls, obj):
+    def applies(cls, obj: Any) -> float | bool | None:
         return ((isinstance(obj, list) and obj and all(cls.applies(o) for o in obj)) or
                 hasattr(obj, 'to_plotly_json') or (isinstance(obj, dict)
                                                    and 'data' in obj and 'layout' in obj))
@@ -123,12 +140,12 @@ class Plotly(PaneBase):
                         element, data=data, parent_path=element_path
                     )
 
-    @param.depends('object', watch=True)
+    @param.depends('object', 'link_figure', watch=True)
     def _update_figure(self):
         import plotly.graph_objs as go
 
         if (self.object is None or type(self.object) is not go.Figure or
-            self.object is self._figure):
+            self.object is self._figure or not self.link_figure):
             return
 
         # Monkey patch the message stubs used by FigureWidget.
@@ -256,7 +273,10 @@ class Plotly(PaneBase):
             params['sizing_mode'] = 'stretch_both'
         return params
 
-    def _get_model(self, doc, root=None, parent=None, comm=None):
+    def _get_model(
+        self, doc: Document, root: Optional[Model] = None,
+        parent: Optional[Model] = None, comm: Optional[Comm] = None
+    ) -> Model:
         PlotlyPlot = lazy_load('panel.models.plotly', 'PlotlyPlot', isinstance(comm, JupyterComm), root)
         model = PlotlyPlot(**self._init_params())
         if root is None:
@@ -265,7 +285,7 @@ class Plotly(PaneBase):
         self._models[root.ref['id']] = (model, parent)
         return model
 
-    def _update(self, ref=None, model=None):
+    def _update(self, ref: str, model: Model) -> None:
         if self.object is None:
             model.update(data=[], layout={})
             model._render_count += 1
