@@ -1,12 +1,12 @@
 from ..config import _config
-from .base import Template, BaseTemplate # noqa
-from .bootstrap import BootstrapTemplate # noqa
-from .fast import FastListTemplate, FastGridTemplate # noqa
-from .material import MaterialTemplate # noqa
-from .theme import DarkTheme, DefaultTheme # noqa
-from .golden import GoldenTemplate # noqa
-from .react import ReactTemplate # noqa
-from .vanilla import VanillaTemplate # noqa
+from .base import BaseTemplate, Template  # noqa
+from .bootstrap import BootstrapTemplate  # noqa
+from .fast import FastGridTemplate, FastListTemplate  # noqa
+from .golden import GoldenTemplate  # noqa
+from .material import MaterialTemplate  # noqa
+from .react import ReactTemplate  # noqa
+from .theme import DarkTheme, DefaultTheme  # noqa
+from .vanilla import VanillaTemplate  # noqa
 
 templates = {
     'bootstrap' : BootstrapTemplate,
