@@ -4,6 +4,7 @@ import pathlib
 import time
 
 import numpy as np
+import param
 import pytest
 
 try:
@@ -188,6 +189,7 @@ def test_cache_clear():
     fn.clear()
     assert fn(0, 0) == 1
 
+@pytest.mark.xdist_group("cache")
 @diskcache_available
 def test_disk_cache():
     global OFFSET
@@ -201,6 +203,7 @@ def test_disk_cache():
     fn.clear()
     assert fn(0, 0) == 1
 
+@pytest.mark.xdist_group("cache")
 @pytest.mark.parametrize('to_disk', (True, False))
 def test_cache_lifo(to_disk):
     if to_disk and diskcache is None:
@@ -214,6 +217,7 @@ def test_cache_lifo(to_disk):
     assert fn(0, 2) == 2 # (0, 0) should be evicted
     assert fn(0, 0) == 1
 
+@pytest.mark.xdist_group("cache")
 @pytest.mark.parametrize('to_disk', (True, False))
 def test_cache_lfu(to_disk):
     if to_disk and diskcache is None:
@@ -227,6 +231,7 @@ def test_cache_lfu(to_disk):
     assert fn(0, 2) == 2 # (0, 1) should be evicted
     assert fn(0, 1) == 2
 
+@pytest.mark.xdist_group("cache")
 @pytest.mark.parametrize('to_disk', (True, False))
 def test_cache_lru(to_disk):
     if to_disk and diskcache is None:
@@ -242,6 +247,7 @@ def test_cache_lru(to_disk):
     assert fn(0, 0) == 0
     assert fn(0, 1) == 2
 
+@pytest.mark.xdist_group("cache")
 @pytest.mark.parametrize('to_disk', (True, False))
 def test_cache_ttl(to_disk):
     if to_disk and diskcache is None:
@@ -252,3 +258,24 @@ def test_cache_ttl(to_disk):
     assert fn(0, 0) == 0
     time.sleep(0.2)
     assert fn(0, 0) == 1
+
+@pytest.mark.xdist_group("cache")
+def test_cache_on_undecorated_parameterized_method():
+    class Model(param.Parameterized):
+        data = param.Parameter(default=1)
+        executions = param.Integer(default=0)
+
+        @cache
+        def expensive_calculation(self, value):
+            self.executions += 1
+            return 2*value
+
+    model = Model()
+    assert model.expensive_calculation(1) == 2
+    assert model.expensive_calculation(1) == 2
+
+    assert model.executions == 1
+
+    assert model.expensive_calculation(2) == 4
+
+    assert model.executions == 2
