@@ -7,6 +7,7 @@ from bokeh.document import Document
 from holoviews import opts
 
 from panel.config import config
+from panel.io.state import state
 from panel.layout import Column
 from panel.pane import HTML, HoloViews, Markdown
 from panel.param import Param
@@ -19,8 +20,6 @@ ACCENT_COLOR = "#f63366" # "lightblue"
 opts.defaults(opts.Ellipse(line_width=3, color=ACCENT_COLOR))
 
 
-
-
 def test_template_theme_parameter():
     template = FastGridTemplate(title="Fast", theme="dark")
     # Not '#3f3f3f' which is for the Vanilla theme
@@ -30,8 +29,6 @@ def test_template_theme_parameter():
 
     assert isinstance(template._get_theme(), FastGridDarkTheme)
 
-
-
 COLLAPSED_ICON = """
 <svg style="stroke: var(--accent-fill-rest);" width="18" height="18" viewBox="0 0 18 18" fill="none" xmlns="http://www.w3.org/2000/svg" slot="collapsed-icon">
             <path d="M15.2222 1H2.77778C1.79594 1 1 1.79594 1 2.77778V15.2222C1 16.2041 1.79594 17 2.77778 17H15.2222C16.2041 17 17 16.2041 17 15.2222V2.77778C17 1.79594 16.2041 1 15.2222 1Z" stroke-linecap="round" stroke-linejoin="round"></path>
@@ -95,7 +92,6 @@ package. You can use it via `pip install awesome-panel-extensions` and
 `from awesome_panel_extensions.frameworks import fast`.
 """ # noqa
 
-
 def _create_hvplot():
     # Generate some data
     cl1 = np.random.normal(loc=2, scale=0.2, size=(200, 200))
@@ -111,18 +107,15 @@ def _create_hvplot():
     plot = clusters * hv.Ellipse(2, 2, 2) * hv.Ellipse(-2, -2, (4, 2))
     return plot
 
-
 def _navigation_menu():
     return HTML(NAVIGATION_HTML)
 
-
 def _sidebar_items():
     return [
         Markdown("## Settings"),
         _navigation_menu(),
     ]
 
-
 def _fast_button_card():
     button = Button(name="Click me", button_type="primary")
     button.param.name.precedence = 0
@@ -152,8 +145,7 @@ def _fast_button_card():
         sizing_mode="stretch_both",
     )
 
-
-def test_app():
+def manualtest_app():
     app = FastGridTemplate(
         title="FastGridTemplate w. Layout Persistence",
         site="Panel",
@@ -175,6 +167,6 @@ def test_app():
     return app
 
 
-if __name__.startswith("bokeh"):
+if state.served:
     config.sizing_mode = "stretch_width"
-    test_app().servable()
+    manualtest_app().servable()
