@@ -1,6 +1,9 @@
+from __future__ import annotations
+
 import unittest.mock
 
 from functools import partial
+from typing import ClassVar, Mapping
 
 import bokeh.core.properties as bp
 import param
@@ -9,10 +12,13 @@ import pytest
 from bokeh.document import Document
 from bokeh.io.doc import patch_curdoc
 from bokeh.models import Div
+
 from panel.layout import Tabs, WidgetBox
 from panel.reactive import Reactive, ReactiveHTML
 from panel.viewable import Viewable
-from panel.widgets import Checkbox, StaticText, TextInput, IntInput
+from panel.widgets import (
+    Checkbox, IntInput, StaticText, TextInput,
+)
 
 
 def test_reactive_default_title():
@@ -57,7 +63,7 @@ def test_param_rename():
 
         a = param.Parameter()
 
-        _rename = {'a': 'b'}
+        _rename: ClassVar[Mapping[str, str | None]] = {'a': 'b'}
 
     obj = ReactiveRename()
 
@@ -463,17 +469,130 @@ def test_reactive_html_templated_children_add_loop_id_and_for_loop_var():
     assert model.looped == ['option']
 
 
-@pytest.mark.parametrize('operator', ['', '+', '-', '*', '\\', '%', '**', '>>', '<<', '>>>', '&', '^', '&&', '||', '??'])
+def test_reactive_html_templated_children_add_loop_id_and_for_loop_var_insensitive_to_spaces():
 
-@pytest.mark.parametrize('sep', [' ', ''])
-def test_reactive_html_scripts_linked_properties_assignment_operator(operator, sep):
+    class TestTemplatedChildren(ReactiveHTML):
 
-    class TestScripts(ReactiveHTML):
+        children = param.List(default=[])
 
-        clicks = param.Integer()
+        _template = """
+        <select id="select">
+        {%- for option in children %}
+          <option id="option">${ option   }</option>
+        {%- endfor %}
+        </select>
+        """
 
-        _template = "<div id='test'></div>"
+    assert TestTemplatedChildren._node_callbacks == {}
+    assert TestTemplatedChildren._inline_callbacks == []
+    assert TestTemplatedChildren._parser.children == {'option': 'children'}
 
-        _scripts = {'render': f'test.onclick = () => {{ data.clicks{sep}{operator}= 1 }}'}
+    test = TestTemplatedChildren(children=['A', 'B', 'C'])
 
-    assert TestScripts()._linked_properties() == ['clicks']
+    assert test._get_template()[0] == """
+        <select id="select-${id}">
+          <option id="option-0-${id}"></option>
+          <option id="option-1-${id}"></option>
+          <option id="option-2-${id}"></option>
+        </select>
+        """
+    model = test.get_root()
+    assert test._attrs == {}
+    assert model.looped == ['option']
+
+
+def test_reactive_html_scripts_linked_properties_assignment_operator():
+
+    for operator in ['', '+', '-', '*', '\\', '%', '**', '>>', '<<', '>>>', '&', '^', '&&', '||', '??']:
+        for sep in [' ', '']:
+
+            class TestScripts(ReactiveHTML):
+
+                clicks = param.Integer()
+
+                _template = "<div id='test'></div>"
+
+                _scripts = {'render': f'test.onclick = () => {{ data.clicks{sep}{operator}= 1 }}'}
+
+            assert TestScripts()._linked_properties() == ['clicks']
+
+
+def test_reactive_html_templated_literal_add_loop_id_and_for_loop_var():
+
+    class TestTemplatedChildren(ReactiveHTML):
+
+        children = param.List(default=[])
+
+        _template = """
+        <select id="select">
+        {%- for option in children %}
+          <option id="option">{{ option }}</option>
+        {%- endfor %}
+        </select>
+        """
+
+    assert TestTemplatedChildren._node_callbacks == {}
+    assert TestTemplatedChildren._inline_callbacks == []
+    assert TestTemplatedChildren._parser.children == {}
+
+    test = TestTemplatedChildren(children=['A', 'B', 'C'])
+
+    assert test._get_template()[0] == """
+        <select id="select-${id}">
+          <option id="option-0-${id}">A</option>
+          <option id="option-1-${id}">B</option>
+          <option id="option-2-${id}">C</option>
+        </select>
+        """
+    model = test.get_root()
+    assert test._attrs == {}
+    assert model.looped == ['option']
+
+
+def test_reactive_html_templated_literal_add_loop_id_and_for_loop_var_insensitive_to_spaces():
+
+    class TestTemplatedChildren(ReactiveHTML):
+
+        children = param.List(default=[])
+
+        _template = """
+        <select id="select">
+        {%- for option in children %}
+          <option id="option">{{option   }}</option>
+        {%- endfor %}
+        </select>
+        """
+
+    assert TestTemplatedChildren._node_callbacks == {}
+    assert TestTemplatedChildren._inline_callbacks == []
+    assert TestTemplatedChildren._parser.children == {}
+
+    test = TestTemplatedChildren(children=['A', 'B', 'C'])
+
+    assert test._get_template()[0] == """
+        <select id="select-${id}">
+          <option id="option-0-${id}">A</option>
+          <option id="option-1-${id}">B</option>
+          <option id="option-2-${id}">C</option>
+        </select>
+        """
+    model = test.get_root()
+    assert test._attrs == {}
+    assert model.looped == ['option']
+
+
+def test_reactive_html_templated_variable_not_in_declared_node():
+    with pytest.raises(ValueError) as excinfo:
+        class TestTemplatedChildren(ReactiveHTML):
+
+            children = param.List(default=[])
+
+            _template = """
+            <select>
+            {%- for option in children %}
+            <option id="option">{{option   }}</option>
+            {%- endfor %}
+            </select>
+            """
+    assert 'could not be expanded because the <select> node' in str(excinfo)
+    assert '{%- for option in children %}' in str(excinfo)
